{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "MM-dd, E",
    MMM => "LLL",
    MMMEd => "MMM d, E",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "MM-dd",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "y-MM",
    yMEd => "y-MM-dd, E",
    yMMM => "y MMM",
    yMMMEd => "y MMM d, E",
    yMMMM => "y MMMM",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "y QQQ",
    yQQQQ => "y QQQQ",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "mi-NZ",
  date_format_full => "y MMMM d, EEEE",
  date_format_long => "y MMMM d",
  date_format_medium => "y MMM d",
  date_format_short => "y-MM-dd",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Hin",
    "T\N{U+016b}",
    "Apa",
    "Par",
    "Mer",
    "Hor",
    "Tap",
  ],
  day_format_narrow => [
    "H",
    "T",
    "A",
    "P",
    "M",
    "H",
    "T",
  ],
  day_format_wide => [
    "R\N{U+0101}hina",
    "R\N{U+0101}t\N{U+016b}",
    "R\N{U+0101}apa",
    "R\N{U+0101}pare",
    "R\N{U+0101}mere",
    "R\N{U+0101}horoi",
    "R\N{U+0101}tapu",
  ],
  day_stand_alone_abbreviated => [
    "Hin",
    "T\N{U+016b}",
    "Apa",
    "Par",
    "Mer",
    "Hor",
    "Tap",
  ],
  day_stand_alone_narrow => [
    "H",
    "T",
    "A",
    "P",
    "M",
    "H",
    "T",
  ],
  day_stand_alone_wide => [
    "R\N{U+0101}hina",
    "R\N{U+0101}t\N{U+016b}",
    "R\N{U+0101}apa",
    "R\N{U+0101}pare",
    "R\N{U+0101}mere",
    "R\N{U+0101}horoi",
    "R\N{U+0101}tapu",
  ],
  era_abbreviated => [
    "BCE",
    "CE",
  ],
  era_narrow => [
    "BCE",
    "CE",
  ],
  era_wide => [
    "BCE",
    "CE",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%d/%m/%y",
  glibc_datetime_format => "Te %A, te %d o %B, %Y %T %Z",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%T",
  language => "Maori",
  month_format_abbreviated => [
    "Kohi",
    "Hui",
    "Pou",
    "Pae",
    "Hara",
    "Pipi",
    "H\N{U+014d}ngo",
    "Here",
    "Mahu",
    "Nuku",
    "Rangi",
    "Haki",
  ],
  month_format_narrow => [
    "K",
    "H",
    "P",
    "P",
    "H",
    "P",
    "H",
    "H",
    "M",
    "N",
    "R",
    "H",
  ],
  month_format_wide => [
    "Kohit\N{U+0101}tea",
    "Huitanguru",
    "Pout\N{U+016b}terangi",
    "Paengawh\N{U+0101}wh\N{U+0101}",
    "Haratua",
    "Pipiri",
    "H\N{U+014d}ngongoi",
    "Hereturik\N{U+014d}k\N{U+0101}",
    "Mahuru",
    "Whiringa-\N{U+0101}-nuku",
    "Whiringa-\N{U+0101}-rangi",
    "Hakihea",
  ],
  month_stand_alone_abbreviated => [
    "Kohi",
    "Hui",
    "Pou",
    "Pae",
    "Hara",
    "Pipi",
    "H\N{U+014d}ngo",
    "Here",
    "Mahu",
    "Nuku",
    "Rangi",
    "Haki",
  ],
  month_stand_alone_narrow => [
    "K",
    "H",
    "P",
    "P",
    "H",
    "P",
    "H",
    "H",
    "M",
    "N",
    "R",
    "H",
  ],
  month_stand_alone_wide => [
    "Kohit\N{U+0101}tea",
    "Huitanguru",
    "Pout\N{U+016b}terangi",
    "Paengawh\N{U+0101}wh\N{U+0101}",
    "Haratua",
    "Pipiri",
    "H\N{U+014d}ngongoi",
    "Hereturik\N{U+014d}k\N{U+0101}",
    "Mahuru",
    "Whiringa-\N{U+0101}-nuku",
    "Whiringa-\N{U+0101}-rangi",
    "Hakihea",
  ],
  name => "Maori New Zealand",
  native_language => "M\N{U+0101}ori",
  native_name => "M\N{U+0101}ori Aotearoa",
  native_script => undef,
  native_territory => "Aotearoa",
  native_variant => undef,
  quarter_format_abbreviated => [
    "HW1",
    "HW2",
    "HW3",
    "HW4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Hauwh\N{U+0101} tuatahi",
    "Hauwh\N{U+0101} tuarua",
    "Hauwh\N{U+0101} tuatoru",
    "Hauwh\N{U+0101} tuawh\N{U+0101}",
  ],
  quarter_stand_alone_abbreviated => [
    "HW1",
    "HW2",
    "HW3",
    "HW4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Hauwh\N{U+0101} tuatahi",
    "Hauwh\N{U+0101} tuarua",
    "Hauwh\N{U+0101} tuatoru",
    "Hauwh\N{U+0101} tuawh\N{U+0101}",
  ],
  script => undef,
  territory => "New Zealand",
  time_format_full => "h:mm:ss a zzzz",
  time_format_long => "h:mm:ss a z",
  time_format_medium => "h:mm:ss",
  time_format_short => "h:mm",
  variant => undef,
  version => 35,
}
